@@ -6,7 +6,7 @@ use Carp;
 use base qw(Lingua::JA::Expand::Base);
 use UNIVERSAL::require;
 
-our $VERSION = '0.00005';
+our $VERSION = '0.00006';
 
 __PACKAGE__->mk_accessors qw(_tokenizer _datasource);
 
@@ -20,8 +20,11 @@ sub expand {
     my $self      = shift;
     my $word      = shift;
     my $threshold = shift || 30;
-    my $text_ref  = $self->datasource->extract_text(\$word);
-    my $word_set  = $self->tokenizer->tokenize( $text_ref, $threshold );
+    if ( $word !~ /./ ) {
+        carp("put any word") and return;
+    }
+    my $text_ref = $self->datasource->extract_text( \$word );
+    my $word_set = $self->tokenizer->tokenize( $text_ref, $threshold );
     return $word_set;
 }
 
@@ -78,6 +81,10 @@ Lingua::JA::Expand - word expander by associatives
   use Lingua::JA::Expand;
   use Data::Dumper;
 
+  my %conf = (
+    yahoo_api_appid => 'xxxxxxxxxxxx',
+  );
+
   my $exp = Lingua::JA::Expand->new(%conf);
 
   # expand the word by associatives 
